from je_auto_control.linux_with_x11.core.display import display

key_backspace = display.keysym_to_keycode(Xlib.XK.string_to_keysym(BackSpace))
key_slash_b = display.keysym_to_keycode(Xlib.XK.string_to_keysym(BackSpace))
key_tab = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Tab))
key_enter = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Return))
key_return = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Return))
key_shift = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Shift_L))
key_ctrl = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Control_L))
key_alt = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Alt_L))
key_pause = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Pause))
key_capslock = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Caps_Lock))
key_esc = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Escape))
key_escape = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Escape))
key_pgup = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Page_Up))
key_pgdn = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Page_Down))
key_pageup = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Page_Up))
key_pagedown = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Page_Down))
key_end = display.keysym_to_keycode(Xlib.XK.string_to_keysym(End))
key_home = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Home))
key_left = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Left))
key_up = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Up))
key_right = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Right))
key_down = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Down))
key_select = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Select))
key_print = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Print))
key_execute = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Execute))
key_prtsc = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Print))
key_prtscr = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Print))
key_prntscrn = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Print))
key_printscreen = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Print))
key_insert = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Insert))
key_del = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Delete))
key_delete = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Delete))
key_help = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Help))
key_win = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Super_L))
key_winleft = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Super_L))
key_winright = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Super_R))
key_apps = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Menu))
key_num0 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(KP_0))
key_num1 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(KP_1))
key_num2 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(KP_2))
key_num3 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(KP_3))
key_num4 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(KP_4))
key_num5 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(KP_5))
key_num6 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(KP_6))
key_num7 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(KP_7))
key_num8 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(KP_8))
key_num9 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(KP_9))
key_multiply = display.keysym_to_keycode(Xlib.XK.string_to_keysym(KP_Multiply))
key_add = display.keysym_to_keycode(Xlib.XK.string_to_keysym(KP_Add))
key_separator = display.keysym_to_keycode(Xlib.XK.string_to_keysym(KP_Separator))
key_subtract = display.keysym_to_keycode(Xlib.XK.string_to_keysym(KP_Subtract))
key_decimal = display.keysym_to_keycode(Xlib.XK.string_to_keysym(KP_Decimal))
key_divide = display.keysym_to_keycode(Xlib.XK.string_to_keysym(KP_Divide))
key_f1 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(F1))
key_f2 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(F2))
key_f3 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(F3))
key_f4 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(F4))
key_f5 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(F5))
key_f6 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(F6))
key_f7 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(F7))
key_f8 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(F8))
key_f9 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(F9))
key_f10 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(F10))
key_f11 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(F11))
key_f12 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(F12))
key_f13 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(F13))
key_f14 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(F14))
key_f15 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(F15))
key_f16 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(F16))
key_f17 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(F17))
key_f18 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(F18))
key_f19 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(F19))
key_f20 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(F20))
key_f21 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(F21))
key_f22 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(F22))
key_f23 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(F23))
key_f24 = display.keysym_to_keycode(Xlib.XK.string_to_keysym(F24))
key_numlock = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Num_Lock))
key_scrolllock = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Scroll_Lock))
key_shiftleft = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Shift_L))
key_shiftright = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Shift_R))
key_ctrlleft = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Control_L))
key_ctrlright = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Control_R))
key_altleft = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Alt_L))
key_altright = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Alt_R))
key_space = display.keysym_to_keycode(Xlib.XK.string_to_keysym(space))
key_newline_n = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Return))
key_newline_r = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Return))
key_newline_t = display.keysym_to_keycode(Xlib.XK.string_to_keysym(Escape))
key_exclam = display.keysym_to_keycode(Xlib.XK.string_to_keysym(exclam))
key_numbersign = display.keysym_to_keycode(Xlib.XK.string_to_keysym(numbersign))
key_percent = display.keysym_to_keycode(Xlib.XK.string_to_keysym(percent))
key_dollar = display.keysym_to_keycode(Xlib.XK.string_to_keysym(dollar))
key_ampersand = display.keysym_to_keycode(Xlib.XK.string_to_keysym(ampersand))
key_quotedbl = display.keysym_to_keycode(Xlib.XK.string_to_keysym(quotedbl))
key_apostrophe = display.keysym_to_keycode(Xlib.XK.string_to_keysym(apostrophe))
key_parenleft = display.keysym_to_keycode(Xlib.XK.string_to_keysym(parenleft))
key_parenright = display.keysym_to_keycode(Xlib.XK.string_to_keysym(parenright))
key_asterisk = display.keysym_to_keycode(Xlib.XK.string_to_keysym(asterisk))
key_equal = display.keysym_to_keycode(Xlib.XK.string_to_keysym(equal))
key_plus = display.keysym_to_keycode(Xlib.XK.string_to_keysym(plus))
key_comma = display.keysym_to_keycode(Xlib.XK.string_to_keysym(comma))
key_minus = display.keysym_to_keycode(Xlib.XK.string_to_keysym(minus))
key_period = display.keysym_to_keycode(Xlib.XK.string_to_keysym(period))
key_slash = display.keysym_to_keycode(Xlib.XK.string_to_keysym(slash))
key_colon = display.keysym_to_keycode(Xlib.XK.string_to_keysym(colon))
key_semicolon = display.keysym_to_keycode(Xlib.XK.string_to_keysym(semicolon))
key_less = display.keysym_to_keycode(Xlib.XK.string_to_keysym(less))
key_greater = display.keysym_to_keycode(Xlib.XK.string_to_keysym(greater))
key_question = display.keysym_to_keycode(Xlib.XK.string_to_keysym(question))
key_at = display.keysym_to_keycode(Xlib.XK.string_to_keysym(at))
key_bracketleft = display.keysym_to_keycode(Xlib.XK.string_to_keysym(bracketleft))
key_bracketright = display.keysym_to_keycode(Xlib.XK.string_to_keysym(bracketright))
key_backslash = display.keysym_to_keycode(Xlib.XK.string_to_keysym(backslash))
key_asciicircum = display.keysym_to_keycode(Xlib.XK.string_to_keysym(asciicircum))
key_underscore = display.keysym_to_keycode(Xlib.XK.string_to_keysym(underscore))
key_grave = display.keysym_to_keycode(Xlib.XK.string_to_keysym(grave))
key_braceleft = display.keysym_to_keycode(Xlib.XK.string_to_keysym(braceleft))
key_bar = display.keysym_to_keycode(Xlib.XK.string_to_keysym(bar))
key_braceright = display.keysym_to_keycode(Xlib.XK.string_to_keysym(braceright))
key_asciitilde = display.keysym_to_keycode(Xlib.XK.string_to_keysym(asciitilde))
